@@ -19,7 +19,7 @@ rm -f $TARGETDIR/icons/*
 
 # get and unpack
 if [ ! -f $MENU ]; then
-    wget -c http://people.canonical.com/~mvo/gnome-app-install/$MENU
+    wget -c http://rookery.canonical.com/~mvo/gnome-app-install/$MENU
 fi
 (cd $TOPDIR ; tar xzvf $HERE/$MENU )
 
